@@ -2,6 +2,8 @@
 """Client for fog service made in python
 Currently only tested in ubuntu 12.04+"""
 import cliapp
+import filelock
+
 import components
 from fog_lib import get_macs, Scheduler
 
@@ -50,23 +52,6 @@ class FogClientApp(cliapp.Application):
         self.snapin_dir = self.settings["snapin_dir"]
         self.interval = self.settings["interval"]
 
-    def cmd_hostname(self, args):
-        """Sets local hostname to the value saved in fog server"""
-        self._load_settings()
-        return [components.hostname(self.fog_host, mac) for mac in get_macs()]
-
-    def cmd_green_fog(self, args):
-        """Shutdowns or reboots the computer at times set in fog server"""
-        self._load_settings()
-        return [components.green_fog(self.fog_host, mac, self.allow_reboot)
-                for mac in get_macs()]
-
-    def cmd_task_reboot(self, args):
-        """Reboots the computer if there is an imaging task waiting"""
-        self._load_settings()
-        return [components.task_reboot(self.fog_host, mac, self.allow_reboot)
-                for mac in get_macs()]
-
     def cmd_snapins(self, args):
         """Downloads and installs the first snapin waiting in the server
            Subsequential runs of the command could be needed.
@@ -90,11 +75,8 @@ class FogClientApp(cliapp.Application):
 
         arguments = [args]
 
-        commands = [self.cmd_hostname,
-                    self.cmd_green_fog,
-                    self.cmd_task_reboot,
-                    self.cmd_snapins,
-                    self.cmd_logins]
+        commands = [self.subcommands[index] for index in self.subcommands
+                    if index not in ("all", "daemon", "help", "help-all")]
 
         scheduler = Scheduler()
         for command in commands:
@@ -105,22 +87,26 @@ class FogClientApp(cliapp.Application):
     def cmd_all(self, args):
         """Execs all commands.
         """
-        self._load_settings()
+        try:
+            with filelock.FileLock("/tmp/fog_client.lock", timeout=10):
+                self._load_settings()
+                arguments = [args]
 
-        arguments = [args]
+                commands = [self.subcommands[index]
+                            for index in self.subcommands
+                            if index not in (
+                                "all", "daemon", "help", "help-all"
+                            )]
 
-        commands = [self.cmd_hostname,
-                    self.cmd_green_fog,
-                    self.cmd_task_reboot,
-                    self.cmd_snapins,
-                    self.cmd_logins]
+                for command in commands:
+                    command(arguments)
 
-        for command in commands:
-            command(arguments)
+        except filelock.FileLockException:
+            print "Locked"
 
 
 if __name__ == '__main__':
-    client_app = FogClientApp(version="0.6.3", description="""
+    client_app = FogClientApp(version="0.6.4", description="""
 Client for fog service made in python
 
 Currently only tested in ubuntu 12.04+""")
